@@ -3,6 +3,7 @@
 import configparser
 import typer
 import boto3
+import os
 
 from os.path import expanduser
 from typing import Optional
@@ -11,6 +12,23 @@ from prettytable import PrettyTable
 app = typer.Typer(help="KPC application for aws profiles", no_args_is_help=True)
 
 
+class IniUtils:
+    @staticmethod
+    def show_file_content(content):
+        output = ''
+        for key in content:
+            output += f"[{key}]\n"
+            for item in content[key]:
+                output += f"{item} = {content[key][item]}\n"
+
+            output += "\n"
+
+        return output
+
+    @staticmethod
+    def check_directory_exists(file_path):
+        os.makedirs(file_path, exist_ok=True)
+
 class Output:
     HEADER = '\033[95m'
     OKBLUE = '\033[94m'
@@ -121,7 +139,12 @@ class AwsResourceQuery:
 
     def list_ec2_instances(self):
         instances = []
-        resp = self.client.describe_instances()
+        try:
+            resp = self.client.describe_instances()
+        except Exception as e:
+            Output.error(e)
+            return []
+
         for reservation in resp['Reservations']:
             for instance in reservation['Instances']:
                 # print(instance)
@@ -139,7 +162,7 @@ class AwsResourceQuery:
         return instances
 
 
-@app.command()  # pragma: no cover
+@app.command()
 def cfg(
         aws_profile: Optional[str] = typer.Argument('default'),
         region: Optional[str] = typer.Argument("us-east-1"),
@@ -162,7 +185,7 @@ def cfg(
     awc.write_config_file()
 
 
-@app.command()  # pragma: no cover
+@app.command()
 def cred(
         aws_profile: Optional[str] = typer.Argument('default'),
         key: Optional[str] = typer.Argument(""),
@@ -185,7 +208,7 @@ def cred(
     awc.write_credentials_file()
 
 
-@app.command()  # pragma: no cover
+@app.command()
 def r53(zone_id: Optional[str] = typer.Argument('')):
     """
     List Route53 hosted zones
@@ -243,7 +266,7 @@ def r53(zone_id: Optional[str] = typer.Argument('')):
         Output.error(e)
 
 
-@app.command()  # pragma: no cover
+@app.command()
 def ec2():
     """
     List EC2 instances
@@ -257,9 +280,10 @@ def ec2():
     table.align['PublicIP'] = 'r'
     table.align['Name'] = 'r'
 
-    table.add_rows(arq.list_ec2_instances())
-
-    print(table.get_string())
+    ec2_instances = arq.list_ec2_instances()
+    if len(ec2_instances) > 0:
+        table.add_rows(ec2_instances)
+        print(table.get_string())
 
 
 if __name__ == '__main__':  # pragma: no cover
